@@ -8,6 +8,7 @@ import (
 	"fmt"
 	"io/ioutil"
 	"os"
+	"path"
 	"path/filepath"
 	"runtime"
 	"strings"
@@ -67,6 +68,10 @@ func flagEnv() map[string]string {
 	}
 }
 
+func Generate() error {
+	return sh.RunWith(flagEnv(), goexe, "generate", path.Join(packageName, "tpl/tplimpl/embedded/generate"))
+}
+
 // Build hugo without git info
 func HugoNoGitInfo() error {
 	ldflags = noGitLdflags
