@@ -20,6 +20,8 @@ import (
 	"strings"
 	texttemplate "text/template"
 
+	"github.com/gohugoio/hugo/tpl/tplimpl/embedded"
+
 	"github.com/eknkc/amber"
 
 	"os"
@@ -682,23 +684,29 @@ func (t *templateHandler) addTemplateFile(name, baseTemplatePath, path string) e
 
 		return t.AddTemplate(name, templ)
 	}
+}
 
+var embeddedTemplatesAliases = map[string][]string{
+	"shortcodes/twitter.html": []string{"shortcodes/tweet.html"},
 }
 
 func (t *templateHandler) loadEmbedded() {
-	t.embedShortcodes()
-	t.embedTemplates()
-}
+	for _, kv := range embedded.EmbeddedTemplates {
+		// TODO(bep) error handling
+		name, templ := kv[0], kv[1]
+		t.addInternalTemplate(name, templ)
+		if aliases, found := embeddedTemplatesAliases[name]; found {
+			for _, alias := range aliases {
+				t.addInternalTemplate(alias, templ)
+			}
 
-func (t *templateHandler) addInternalTemplate(prefix, name, tpl string) error {
-	if prefix != "" {
-		return t.AddTemplate("_internal/"+prefix+"/"+name, tpl)
+		}
 	}
-	return t.AddTemplate("_internal/"+name, tpl)
+
 }
 
-func (t *templateHandler) addInternalShortcode(name, content string) error {
-	return t.addInternalTemplate("shortcodes", name, content)
+func (t *templateHandler) addInternalTemplate(name, tpl string) error {
+	return t.AddTemplate("_internal/"+name, tpl)
 }
 
 func (t *templateHandler) checkState() {
